% Read and organize data in Excel file to be used by Stata

clear all

% =======================================
% 1. Macro data from OECD EO
% =======================================
GetDataEO94;     

tt    = 42:53;    % 2001-2012

% Save CPI or CPIH 2001-2012 for some countries
Pcpi  = CPI(21:end,tt);
Phicp = CPIH(21:end,tt);
P = Pcpi;
P([1 3 7 10:12],:) = Phicp([1 3 7 10:12],:);
save matlabdata\OECD_PriceLevels P

% Save macro data
CA  = CBGDPR(:,tt);
IH  = 100*IHV(:,tt)./GDPV(:,tt);     % Gross fixed capital formation, housing, real
U   = UNR(:,tt);
Y   = GDPV(:,tt)./POP1500(:,tt);     % Real GDP per capita
CP  = CPV(:,tt)./POP1500(:,tt);      % Real private consumption per capita
DG  = GGFLQ(:,tt);                   % General gvt gross financial liabilities (% of GDP)

save matlabdata\OECD_Data CA IH U Y CP DG cty


% =======================================
% 2. House price data from OECD EO
% =======================================
clear all

% EO94: 2005-2012
[x1,x2,x3]  = xlsread('OECD_EO_HousePrices','EO94',['b4:i23']);
dPH = x1;

% EO92: 2004
[x1,x2,x3]  = xlsread('OECD_EO_HousePrices','EO92',['b4:b23']);
dPH = [x1 dPH];
PH  = cumprod(1+dPH/100,2);

% EO90: 2003
[x1,x2,x3]  = xlsread('OECD_EO_HousePrices','EO90',['b4:b23']);
dPH = [x1 dPH];
PH = [PH(:,1)./(1+x1/100) PH];

% EO85: 2001-2002
[x1,x2,x3]  = xlsread('OECD_EO_HousePrices','EO85',['b4:c23']);
dPH = [x1 dPH];
PH = [PH(:,1)./(1+x1(:,2)/100) PH];
PH = [PH(:,1)./(1+x1(:,1)/100) PH];

OECD_PHreal = 100 * PH ./ (PH(:,7)*ones(1,size(PH,2)));

% Sort countries as in OECD EO
ii = [1 2 3 18 7 4 ...
      16 5 6 19 8 9 10 ...    
      11 12 13 15 14 17 20];
OECD_PHreal = OECD_PHreal(ii,:);
save matlabdata\OECD_HousePrices OECD_PHreal


% =======================================
% 3. House price data from BIS
% =======================================
GetDataBIS;

% Impute value for CZ 2007 from alternative series
CZEalt = CZEalt*(CZE(8)/CZEalt(8));
CZE(7) = CZEalt(7);

% Matrix with nominal house prices 2001-2012, countries ordered as in OECD EO
PHnom = [AUT CZE EST HUN ISL ISR LUX MEX POL PRT SVK SVN]';

% Load CPI or HICP into P, generated by GetDataEO94
load matlabdata\OECD_PriceLevels
BIS_PHreal = PHnom ./ P;

% Normalize house prices in 2007 to 100
BIS_PHreal = 100 * BIS_PHreal ./ (BIS_PHreal(:,7)*ones(1,size(BIS_PHreal,2)));
save matlabdata\BIS_HousePrices BIS_PHreal


% ===============================================
% 4. Financial stocks from OECD National Accounts 
% ===============================================
clear all

% HH debt relative net disp inc, 2001-2012
[x1,x2,x3]  = xlsread('OECD_FinancialIndicators','Private sector debt',['j5:u36']);
hhDebt = x1;

% HH financial assets relative net disp inc, 2001-2012
[x1,x2,x3]  = xlsread('OECD_FinancialIndicators','Private sector debt',['j37:u68']);
hhAssets = x1;

% Sort countries as in OECD EO
ii = [1 3 4 30 10 6 ...
      28 8 9 31 11 14 16 ... 
      17 18 21 23 22 29 32 ...
      2 5 7 12 13 15 19 ...
      20 24 25 26 27];
hhDebt   = hhDebt(ii,:);
hhAssets = hhAssets(ii,:);

save matlabdata\OECD_FinancialBalances hhDebt hhAssets;

% =======================================
% 5. Compile relevant data
% =======================================

clear all

load matlabdata\OECD_Data;                % CA IH U CP Y DG cty, 2001-2012 
load matlabdata\OECD_HousePrices          % OECD_PHreal, 2001-2012 
load matlabdata\BIS_HousePrices           % BIS_PHreal, 2001-2012
load matlabdata\OECD_FinancialBalances    % hhDebt hhAssets, 2001-2012;

PH = [OECD_PHreal; BIS_PHreal];
clear OECD_PHreal BIS_PHreal;

dPH = 100*(PH(:,12)./PH(:,7)-1);

dPHpre  = average(100*(PH(:,3:7)./PH(:,2:6)-1),4);
CApre   = average(CA(:,3:7));
IHpre   = average(IH(:,3:7));

dU      = U(:,12) - U(:,7);
dY      = 100*(Y(:,12)./Y(:,7)-1);
dCP     = 100*(CP(:,12)./CP(:,7)-1);
dYpre   = average(100*(Y(:,3:7)./Y(:,2:6)-1));
dCPpre  = average(100*(CP(:,3:7)./CP(:,2:6)-1));

hhWealth = hhAssets - hhDebt;

dWealthpre = average(100*(hhWealth(:,3:7)./hhWealth(:,2:6)-1),4);
dDebtpre   = average(100*(hhDebt(:,3:7)./hhDebt(:,2:6)-1),4);

% Auxilliary variables to be used in robustness checks or to examine
% implications of the analysis
auxCA = NaN*ones(size(CApre,1),7); auxdCP = auxCA; auxdDebt = auxCA; auxDebt = auxCA;
for i = 2:8
    auxDebt(:,i-1)  = hhDebt(:,i+4);
    auxdDebt(:,i-1) = average(100*(hhDebt(:,i:i+4)./hhDebt(:,i-1:i+3)-1),4);
    auxCA(:,i-1)    = average(CA(:,i:i+4));
end

% Only keep debt and wealth data from 2007 
hhDebt   = hhDebt(:,7);
hhWealth = hhWealth(:,7);
DG       = DG(:,7);

% Add Swedish data for 2008-2012 corresponding to 2007 position
% Assumes that SWE is ordered as cty no 19
ctystr = cellstr(cty);
ctystr{end+1} = 'SWE2008';
ctystr{end+1} = 'SWE2009';
ctystr{end+1} = 'SWE2010';
ctystr{end+1} = 'SWE2011';
ctystr{end+1} = 'SWE2012';
hhDebt   = [hhDebt; auxDebt(19,3:7)'];
dDebtpre = [dDebtpre; auxdDebt(19,3:7)'];
CApre    = [CApre; auxCA(19,3:7)'];

xlswrite('Data.xlsx',cellstr('Country'),1,'A1');
xlswrite('Data.xlsx',ctystr,1,'A2');

xlswrite('Data.xlsx',{'hhDebt','dDebtpre','CApre'},1,'B1');
xlswrite('Data.xlsx',[hhDebt dDebtpre CApre],1,'B2');

xlswrite('Data.xlsx',{'dU','dPH','dY','dCP','IHpre','dPHpre','hhWealth','dWealthpre','dYpre','dCPpre','DG'},1,'E1');
xlswrite('Data.xlsx',[dU dPH dY dCP IHpre dPHpre hhWealth dWealthpre dYpre dCPpre DG],1,'E2');

